@@ -75,6 +75,7 @@ class Player(Gtk.Box):
         toolbar = Gtk.Toolbar()
         toolbar.set_style(Gtk.ToolbarStyle.ICONS)
         toolbar.get_style_context().add_class(
+                #Gtk.STYLE_CLASS_MENUBAR)
                 Gtk.STYLE_CLASS_PRIMARY_TOOLBAR)
         toolbar.set_show_arrow(False)
         toolbar.set_icon_size(ICON_SIZE)
@@ -384,7 +385,7 @@ class Player(Gtk.Box):
 
     def on_volume_value_changed(self, volume_button, volume):
         self.playbin.set_volume(volume ** 3)
-        self.app.conf['volume'] = volume
+        self.app.conf['volume'] = volume ** 3
         if self.playbin.get_mute():
             self.playbin.set_mute(False)
 
